package com.usky.iot.service.impl;

import com.usky.common.core.exception.BusinessException;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.iot.domain.BaseAlarmType;
import com.usky.iot.domain.BaseAppInfo;
import com.usky.iot.mapper.BaseAppInfoMapper;
import com.usky.iot.service.BaseAppInfoService;
import com.usky.common.mybatis.core.AbstractCrudService;
import org.springframework.stereotype.Service;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;

/**
 * <p>
 * APP用户心跳信息 服务实现类
 * </p>
 *
 * @author han
 * @since 2024-03-29
 */
@Service
public class BaseAppInfoServiceImpl extends AbstractCrudService<BaseAppInfoMapper, BaseAppInfo> implements BaseAppInfoService {

    public String getIpAddress(HttpServletRequest request) {
        String ip = request.getHeader("X-Forwarded-For");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        return ip;
    }

    public static HttpServletRequest getHttpServletRequest() {
        RequestAttributes requestAttributes = RequestContextHolder.getRequestAttributes();
        if(requestAttributes == null){
            return null;
        }

        return ((ServletRequestAttributes) requestAttributes).getRequest();
    }

    @Override
    public void add(BaseAppInfo baseAppInfo){
        HttpServletRequest request = getHttpServletRequest();
        String accessIp = getIpAddress(request);
        baseAppInfo.setAccessIp(accessIp);
        baseAppInfo.setCreateBy(SecurityUtils.getUsername());
        baseAppInfo.setCreateTime(LocalDateTime.now());
        baseAppInfo.setTenantId(SecurityUtils.getTenantId());
        this.save(baseAppInfo);
    }
}
